<div align="center">
    <h1>Pulumi CTFd-CM Provider</h1>
    <p><b>Let's code your CTF(d), with <a href="https://github.com/ctfer-io/ctfd-chall-manager">Chall-Manager</a></b><p>
    <a href="https://pkg.go.dev/github.com/ctfer-io/pulumi-ctfdcm"><img src="https://shields.io/badge/-reference-blue?logo=go&style=for-the-badge" alt="reference"></a>
    <a href=""><img src="https://img.shields.io/github/license/ctfer-io/pulumi-ctfdcm?style=for-the-badge" alt="License"></a>
	<br>
	<a href="https://github.com/ctfer-io/pulumi-ctfdcm/actions/workflows/codeql-analysis.yaml"><img src="https://img.shields.io/github/actions/workflow/status/ctfer-io/pulumi-ctfdcm/codeql-analysis.yaml?style=for-the-badge&label=CodeQL" alt="CodeQL"></a>
    <a href="https://securityscorecards.dev/viewer/?uri=github.com/ctfer-io/pulumi-ctfdcm"><img src="https://img.shields.io/ossf-scorecard/github.com/ctfer-io/pulumi-ctfdcm?label=openssf%20scorecard&style=for-the-badge" alt="OpenSSF Scoreboard"></a>
</div>

## Context

The CTFd-CM Resource Provider lets you manage [CTFd plugin for Chall-Manager](https://github.com/ctfer-io/ctfd-chall-manager) resources.

## SDK

To install the provider, refer to [this documentation](/docs/installation-configuration.md).

For more information on how to use the SDK in your favorite language, refer to [this documentation](/docs/_index.md).
